#include <QVBoxLayout>
#include <QVBoxLayout>
#include <QPushButton>
#include <QFileDialog>
#include <QLabel>
#include "mainwindow.h"
#include "filterdxfrw.h"
MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    QVBoxLayout *mainLayout = new QVBoxLayout;
    QHBoxLayout *butLayout = new QHBoxLayout;
    fileLine = new QLineEdit(this);
    butLayout->addWidget(fileLine);
    QWidget *w = new QPushButton("sel. file");
    butLayout->addWidget(w);
    connect(w, SIGNAL(clicked()), this, SLOT(openFile()));
    mainLayout->addLayout(butLayout);
    w = new QLabel("Layer list:");
    mainLayout->addWidget(w);
    layerText = new QTextEdit;
    layerText->setAcceptRichText ( false );
    mainLayout->addWidget(layerText);
    w = new QLabel("last MText:");
    mainLayout->addWidget(w);
    textText = new QTextEdit;
    textText->setAcceptRichText ( false );
    mainLayout->addWidget(textText);
    butLayout = new QHBoxLayout;
    w = new QLabel("number");
    butLayout->addWidget(w);
    doubleLine = new QLineEdit;
    butLayout->addWidget(doubleLine);
    mainLayout->addLayout(butLayout);

    butLayout = new QHBoxLayout;
    w = new QPushButton("save");
    butLayout->addWidget(w);
    connect(w, SIGNAL(clicked()), this, SLOT(saveFile()));
    cpCombo = new QComboBox(this);
    cpCombo->setEditable ( false );
    QStringList cps;
    cps << "ANSI_874 Latin/Thai" << "ANSI_932 Japanese"
            << "ANSI_936 Chinese simplified GBK" << "ANSI_949 Korean"
            << "ANSI_950 Chinese SAR" << "ANSI_1250 Central/East Europe" << "ANSI_1251 Cyrillic"
            << "ANSI_1252 Western Europe" << "ANSI_1253 Greek" << "ANSI_1254 Turkish"
            << "ANSI_1255 Hebrew" <<  "ANSI_1256 Arabic" <<  "ANSI_1257 Baltic"
            <<  "ANSI_1258 Vietnamese" <<  "unknown";
    cpCombo->addItems ( cps );
    butLayout->addWidget(cpCombo);
    mainLayout->addLayout(butLayout);

    w = new QPushButton("close");
    connect(w, SIGNAL(clicked()), this, SLOT(close()));
    mainLayout->addWidget(w);

    w = new QWidget;
    w->setLayout(mainLayout);
    setCentralWidget(w);
}

MainWindow::~MainWindow()
{
    
}

void MainWindow::openFile(){
    QString cp;
    QString fileName = QFileDialog::getOpenFileName(this,
        tr("Open File"), "", tr("dxf Files (*.dxf)"));
    doubleLine->clear();
    textText->clear();
    layerText->clear();
    if (!fileName.isNull() ) {
        fileLine->setText(fileName);
        FilterDXFRW *pep = new FilterDXFRW();
        pep->fileImport(fileName, &cp, doubleLine, layerText, textText);
        if (cp.isEmpty()) cp = "unknown";
        cpCombo->setCurrentIndex ( indexForLabel(cp) );
    }
}

void MainWindow::saveFile(){
    QString fileName;
    QStringList filters;
    DRW::Version ver;
    filters << "dxf R12 (*.dxf)"
            << "dxf R14 (*.dxf)"
            << "dxf 2000 (*.dxf)"
            << "dxf 2004 (*.dxf)"
            << "dxf 2007 (*.dxf)"
            << "dxf R2010 (*.dxf)";

    QFileDialog dialog(this, tr("Save dxf as..."));
    dialog.setFileMode(QFileDialog::AnyFile);
    dialog.setLabelText ( QFileDialog::Accept, "Save" );
    dialog.setNameFilters(filters);
    dialog.setOption(QFileDialog::DontUseNativeDialog, true);
    QStringList fileNames;
    if (dialog.exec()) {
        fileNames = dialog.selectedFiles();
        fileName = fileNames.at(0);
        if (dialog.selectedNameFilter() == "dxf R12 (*.dxf)")
            ver = DRW::AC1009;
        else if (dialog.selectedNameFilter() == "dxf R14 (*.dxf)")
            ver = DRW::AC1014;
        else if (dialog.selectedNameFilter() == "dxf 2000 (*.dxf)")
            ver = DRW::AC1015;
        else if (dialog.selectedNameFilter() == "dxf 2004 (*.dxf)")
            ver = DRW::AC1018;
        else if (dialog.selectedNameFilter() == "dxf 2007 (*.dxf)")
            ver = DRW::AC1021;
        else //dxf R2010 (*.dxf)
            ver = DRW::AC1024;
    }
    if (!fileName.isNull() ) {
        FilterDXFRW *pep = new FilterDXFRW();
        QFileInfo fi( fileName );
        fileName = fi.absolutePath() + "/" + fi.completeBaseName() + ".dxf";
        QStringList cp = cpCombo->currentText() .split(' ');
        pep->fileExport(fileName, ver, cp.at(0), layerText, textText);
    }
}

int MainWindow::indexForLabel(QString cp){
    if (cp == "ANSI_874")
        return 0;
    if (cp == "ANSI_932")
        return 1;
    if (cp == "ANSI_936")
        return 2;
    if (cp == "ANSI_949")
        return 3;
    if (cp == "ANSI_950")
        return 4;
    if (cp == "ANSI_1250")
        return 5;
    if (cp == "ANSI_1251")
        return 6;
    if (cp == "ANSI_1252")
        return 7;
    if (cp == "ANSI_1253")
        return 8;
    if (cp == "ANSI_1254")
        return 9;
    if (cp == "ANSI_1255")
        return 10;
    if (cp == "ANSI_1256")
        return 11;
    if (cp == "ANSI_1257")
        return 12;
    if (cp == "ANSI_1258")
        return 13;
    return 14;
}
